pub enum CacheErr {
RectTooLarge(usize),
DontFit(usize),
}Expand description
Reason of cache failure.
Variants
RectTooLarge(usize)
At least one of the queued rects is too big to fit into the cache by itself. Contains the number of rects that was added to the cache.
DontFit(usize)
Not all of the requested glyphs fit into the cache, even after clearing all previous cached rects. Contains the number of rects that was added to the cache.
Implementations